/*
 * 这个代码，是展示如何使用本sdk的函数的示例代码，
 * 完整的API说明，可以直接在头文件中看到。
 * 建议本代码只作为参考示例，
 * 而不是复制到项目中直接使用。
 * */

#include <stdio.h>
#include "wx_human_matting_c_api.h"

int test_remove_background(WXHumanMatting_t *matting, const char* inputFile)
{
    printf("removeBackground testing...\n");
    int res = 0;
    WXImage_t *inImg = NULL, *bkImg = NULL, *resImg = NULL;
    res = WXImage_FromFile(inputFile, &inImg);
    if (res != 0) {
        printf("failed in WXImage_FromFile: %d, %s\n", res, WXSDK_GetLastErrorMsg());
        return res;
    }
    res = WXImage_FromColor(WXImage_Width(inImg),
                            WXImage_Height(inImg),
                            255, 0,0,
                            &bkImg);
    if (res != 0) {
        printf("failed in WXImage_FromColor: %d, %s\n", res, WXSDK_GetLastErrorMsg());
        WXImage_Release(inImg);
        return res;
    }

    // 此处，bkImg初始化成红色背景图片，
    // 对于付费版SDK，bkImg参数传入NULL，可以返回透明背景图，
    // 但如果是免费版SDK，bkImg传入NULL，则会得到白色背景图，
    res = WXHumanMatting_RemoveBackground(matting, inImg, bkImg, &resImg);
    if (res != 0) {
        printf("failed in WXHumanMatting_RemoveBackground: %d, %s\n", res, WXSDK_GetLastErrorMsg());
        WXImage_Release(inImg);
        WXImage_Release(bkImg);
        return res;
    }
    res = WXImage_ToFile(resImg, "./res_bg.png");
    if (res != 0) {
        printf("failed in WXImage_ToFile: %d, %s\n", res, WXSDK_GetLastErrorMsg());
        WXImage_Release(inImg);
        WXImage_Release(bkImg);
        WXImage_Release(resImg);
        return res;
    }
    printf("save transparent background image to file ./res_bg.png \n\n");
    WXImage_Release(inImg);
    WXImage_Release(bkImg);
    WXImage_Release(resImg);
    return 0;
}

int main(int argc, char *argv[])
{
    /*
     * 这个代码，是展示如何使用本sdk的函数的示例代码，
     * 完整的API说明，可以直接在头文件中看到。
     * 建议本代码只作为参考示例，
     * 而不是复制到项目中直接使用。
     * */
    const char *lic_file = "./my.lic";
    const WXDeviceType deviceType = kDeviceCPU; // kDeviceGPU
    WXHumanMatting_t *matting = NULL;

    int i;
    int n = 1;
    int res;

    printf("sdk version: %s\n", WXSDK_Version());

    res = WXSDKInitWithLicenseFile("换成你的appkey", lic_file);
    if (res != 0) {
        printf("failed in WXSDKInitWithLicenseFile: %d, %s\n", res, WXSDK_GetLastErrorMsg());
        return -1;
    }

    // 创建WXHumanMatting对象对象，用来做抠图处理（而不是用来做证件照处理）
    // 建议一个进程（或者线程）只创建一个WXHumanMatting对象，
    // 而不是每处理一张图片，都创建一个新的对象
    // 如果只是处理证件照业务（而不是抠图），则不需要本对象
    res = WXHumanMatting_Create(deviceType, &matting);
    if (res != 0) {
        printf("failed in WXHumanMatting_Create: %d, %s\n", res, WXSDK_GetLastErrorMsg());
        return -1;
    }

    // 对抠图接口，循环测试n次
    for (i = 0; i < n; i ++) {
        test_remove_background(matting, "./tests/test1.jpg");
    }

    /* 记得务必释放matting */
    WXHumanMatting_Release(matting);

    printf("test finish\n");

    /* 进程退出前调用WXHumanMatting_Terminate */
    WXSDK_Terminate();

    return 0;
}
