/**
 * @file wx_api.h
 */

#ifndef WX_HUMAN_SEG_WX_API_H
#define WX_HUMAN_SEG_WX_API_H

#ifndef WX_API
#ifdef WIN32
#ifdef DLL_EXPORT
#define WX_API __declspec(dllexport)
#else
#define WX_API __declspec(dllimport)
#endif
#else
#define WX_API
#endif
#endif

/** 推理引擎设备类型 */
typedef enum WXDeviceType{
    /** CPU */
    kDeviceCPU = 0,

    /** GPU */
    kDeviceGPU = 1
} WXDeviceType;

/**
 * @section errorCode SDK错误码
 错误都是通过异常WXException抛出，
 错误编码通过WXException::errCode() 给出，
 具体错误描述通过WXException::what() 给出

 以下为主要错误编码：
    WX_SEGE_UnkErr                                     = 1500001     // 未知错误
    WX_SEGE_MemoryAlloc                                = 1500002     // 内存分配失败
    WX_SEGE_IllegalArgument                            = 1500003     // 参数错误
    WX_SEGE_EngineInitFail                             = 1500004     // AI引擎初始化失败
    WX_SEGE_LoadModelFail                              = 1500005     // AI模型初始化失败
    WX_SEGE_CreateModelSessionFail                     = 1500006     // 创建推理session失败
    WX_SEGE_IllegalState                               = 1500007     // 状态错误
    WX_SEGE_Preprocess01Fail                           = 1500008     // 预处理失败
    WX_SEGE_CudaError                                  = 1500009     // CUDA调用失败
    WX_SEGE_InferError                                 = 1500010     // 推理失败
    WX_SEGE_CreateInferInputOutputError                = 1500011     // 创建推理输入或者输出失败
    WX_SEGE_GetModelOutData                            = 1500012     // 获取推理结果是把
    WX_SEGE_SDKExpired                                 = 1500014     // SDK已过期
    WX_SEGE_SDKLicenseInvalid                          = 1500015     // SDK无效
    WX_SEGE_ImageEncode                                = 1500016     // 图片解码失败
    WX_SEGE_ImageDecode                                = 1500017     // 图片编码失败
    WX_SEGE_FaceDetectEngineInitFail                   = 1500018     // 人脸检测AI引擎初始化失败
    WX_SEGE_FaceDetectEngineNotInited                  = 1500019     // 人脸检测AI引擎未初始化
    WX_SEGE_FaceDetectFail                             = 1500020     // 人脸检测失败
    WX_SEGE_NoFace                                     = 1500021     // 图片中没有人脸
    WX_SEGE_NoPerson                                   = 1500022     // 图片中没有人像
    WX_SEGE_NotImplemented                             = 1500023     // 未实现的方法
    WX_SEGE_PersonSegEngineNotInited                   = 1500024     // 人体分析引擎初始化失败
    WX_SEGE_KeyNotFound                                = 1500025     // 关键字找不到
    WX_SEGE_TypeError                                  = 1500026     // 类型错误
    WX_SEGE_OperationNotAllowed                        = 1500027     // 操作不容许
    WX_SEGE_OSNotAllowed                               = 1500028     // 不容许在本系统上运行
    WX_SEGE_GetModelInput                              = 1500029     // 获取引擎输入失败
*/

#endif //WX_HUMAN_SEG_WX_API_H
